import 'package:json_annotation/json_annotation.dart';
part 'bvn_response.g.dart';

/// Data class for BVN Verification Response
@JsonSerializable(explicitToJson: true)
class BVNResponse {
  @JsonKey(name: 'status_code')
  int statusCode;
  @JsonKey(name: 'status')
  String status;
  @JsonKey(name: 'message')
  String message;
  @JsonKey(name: 'results')
  Results results;

  BVNResponse(this.statusCode, this.status, this.message, this.results);

  factory BVNResponse.fromJson(Map<String, dynamic> json) => _$BVNResponseFromJson(json);
  Map<String, dynamic> toJson()=> _$BVNResponseToJson(this);
}

/// Data class for BVN Verification Response Results
@JsonSerializable(fieldRename: FieldRename.snake, explicitToJson: true)
class Results {
  String requestReference;
  String bvnNumber;
  String nameOnCard;
  dynamic enrolmentBranch;
  dynamic enrolmentBank;
  dynamic formattedRegistrationDate;
  String levelOfAccount;
  String nin;
  String watchlisted;
  String verificationStatus;
  String serviceType;
  PersonalInfo personalInfo;
  ResidentialInfo residentialInfo;

  Results(this.requestReference,
      this.bvnNumber,
      this.nameOnCard,
      this.enrolmentBranch,
      this.enrolmentBank,
      this.formattedRegistrationDate,
      this.levelOfAccount,
      this.nin,
      this.watchlisted,
      this.verificationStatus,
      this.serviceType,
      this.personalInfo,
      this.residentialInfo);

  factory Results.fromJson(Map<String, dynamic> json) => _$ResultsFromJson(json);

  Map<String, dynamic> toJson() => _$ResultsToJson(this);
}

/// Data class for BVN Verification Residential Info Response
@JsonSerializable(fieldRename: FieldRename.snake)
class ResidentialInfo {
  String stateOfResidence;
  String lgaOfResidence;
  String residentialAddress;

  ResidentialInfo(
      this.stateOfResidence, this.lgaOfResidence, this.residentialAddress);

  factory ResidentialInfo.fromJson(Map<String, dynamic> json) => _$ResidentialInfoFromJson(json);

  Map<String, dynamic> toJson() => _$ResidentialInfoToJson(this);
}

/// Data class for BVN Verification Personal Info Response

@JsonSerializable(fieldRename: FieldRename.snake)
class PersonalInfo {
  String firstName;
  String middleName;
  String lastName;
  String fullName;
  String email;
  String gender;
  String phoneNumber;
  String phoneNumber2;
  String dateOfBirth;
  String formattedDateOfBirth;
  String lgaOfOrigin;
  String stateOfOrigin;
  String nationality;
  String maritalStatus;

  PersonalInfo(
      this.firstName,
      this.middleName,
      this.lastName,
      this.fullName,
      this.email,
      this.gender,
      this.phoneNumber,
      this.phoneNumber2,
      this.dateOfBirth,
      this.formattedDateOfBirth,
      this.lgaOfOrigin,
      this.stateOfOrigin,
      this.nationality,
      this.maritalStatus);

  factory PersonalInfo.fromJson(Map<String, dynamic> json) => _$PersonalInfoFromJson(json);

  Map<String, dynamic> toJson() => _$PersonalInfoToJson(this);
}
