import 'package:json_annotation/json_annotation.dart';
part 'nin_response.g.dart';

/// Data class for NIN Verification Response

@JsonSerializable(fieldRename: FieldRename.snake, explicitToJson: true)
class NINResponse {
  int statusCode;
  String status;
  String message;
  Results results;

  NINResponse(this.statusCode, this.status, this.message, this.results);

  factory NINResponse.fromJson(Map<String, dynamic> json) =>
      _$NINResponseFromJson(json);

  Map<String, dynamic> toJson() => _$NINResponseToJson(this);

}

/// Data class for NIN Verification Result Response

@JsonSerializable(fieldRename: FieldRename.snake, explicitToJson: true)
class Results {
  String requestReference;
  String ninNumber;
  dynamic documentNo;
  String verificationStatus;
  String serviceType;
  PersonalInfo personalInfo;
  NextOfKin nextOfKin;
  ResidentialInfo residentialInfo;
  IndigeneInfo indigeneInfo;
  EducationProfession educationProfession;

  Results(
      this.requestReference,
      this.ninNumber,
      this.documentNo,
      this.verificationStatus,
      this.serviceType,
      this.personalInfo,
      this.nextOfKin,
      this.residentialInfo,
      this.indigeneInfo,
      this.educationProfession);
  factory Results.fromJson(Map<String, dynamic> json) =>
      _$ResultsFromJson(json);

  Map<String, dynamic> toJson() => _$ResultsToJson(this);
}

/// Data class for NIN Verification Education Info Response

@JsonSerializable(fieldRename: FieldRename.snake, explicitToJson: true)
class EducationProfession {
  String educationalLevel, employmentStatus, profession;

  EducationProfession(
      this.educationalLevel, this.employmentStatus, this.profession);

  factory EducationProfession.fromJson(Map<String, dynamic> json) =>
      _$EducationProfessionFromJson(json);

  Map<String, dynamic> toJson() => _$EducationProfessionToJson(this);
}

@JsonSerializable(fieldRename: FieldRename.snake, explicitToJson: true)
class IndigeneInfo {
  String lgaOfOrigin,
      placeOfOrigin,
      stateOfOrigin,
      lgaOfBirth,
      stateOfBirth,
      countryOfBirth;

  IndigeneInfo(this.lgaOfOrigin, this.placeOfOrigin, this.stateOfOrigin,
      this.lgaOfBirth, this.stateOfBirth, this.countryOfBirth);

  factory IndigeneInfo.fromJson(Map<String, dynamic> json) =>
      _$IndigeneInfoFromJson(json);

  Map<String, dynamic> toJson() => _$IndigeneInfoToJson(this);
}

/// Data class for NIN Verification Residential Info Response

@JsonSerializable(fieldRename: FieldRename.snake, explicitToJson: true)
class ResidentialInfo {
  String address, lgaOfResidence, stateOfResidence, residenceStatus;

  ResidentialInfo(this.address, this.lgaOfResidence, this.stateOfResidence,
      this.residenceStatus);

  factory ResidentialInfo.fromJson(Map<String, dynamic> json) =>
      _$ResidentialInfoFromJson(json);

  Map<String, dynamic> toJson() => _$ResidentialInfoToJson(this);
}

@JsonSerializable(fieldRename: FieldRename.snake, explicitToJson: true)
class NextOfKin {
  String firstname, surname, address, lga, town, state;

  NextOfKin(this.firstname, this.surname, this.address, this.lga, this.town,
      this.state);

  factory NextOfKin.fromJson(Map<String, dynamic> json) =>
      _$NextOfKinFromJson(json);

  Map<String, dynamic> toJson() => _$NextOfKinToJson(this);
}

/// Data class for NIN Verification Personal Info Response

@JsonSerializable(fieldRename: FieldRename.snake, explicitToJson: true)
class PersonalInfo {
  String title, firstName, middleName, lastName, fullName, maidenName, gender;
  String email,
      phoneNumber,
      dateOfBirth,
      formattedDateOfBirth,
      height,
      maritalStatus;
  String imageUrl, religion, signature;

  PersonalInfo(this.title, this.firstName, this.middleName, this.lastName,
      this.fullName, this.maidenName, this.gender, this.email, this.phoneNumber,
      this.dateOfBirth, this.formattedDateOfBirth, this.height,
      this.maritalStatus, this.imageUrl, this.religion, this.signature);

  factory PersonalInfo.fromJson(Map<String, dynamic> json) =>
      _$PersonalInfoFromJson(json);

  Map<String, dynamic> toJson() => _$PersonalInfoToJson(this);


}
