import 'dart:io';

/// This File contains Data classes for Verification services Request.
/// Each class uses the manual Json Serialization and has ```map()``` ,
/// ```fromJson(json)``` and ```tojson()``` methods required by the json
/// serialization package for encoding and decoding using ```jsonEncode``` and
/// ```jsonDecode()```

/// Data class for BVN Verification Request

class BVNRequest {
  String firstName, lastName, bvnNumber, phoneNumber, dob;

  BVNRequest({this.firstName = "", this.lastName, this.bvnNumber,
      this.phoneNumber, this.dob});



//  String get firstName => _firstName;
//  String get lastName => _lastName;
//  String get bvnNumber => _bvnNumber;
//  String get phoneNumber => _phoneNumber;
//  String get dob => _dob;

  BVNRequest.map(dynamic obj) {
    this.firstName = obj["first_name"];
    this.lastName = obj["last_name"];
    this.bvnNumber = obj["bvn_number"];
    this.phoneNumber = obj["phone_number"];
    this.dob = obj["dob"];
  }

  BVNRequest.fromJson(Map<String, dynamic> json)
    : firstName = json['first_name'],
     lastName = json['last_name'],
     bvnNumber = json['bvn_number'],
     phoneNumber = json['phone_number'],
     dob = json['dob'];

  Map<String, dynamic> toJson() {
    var map = new Map<String, dynamic>();
    map["first_name"] = firstName;
    map["last_name"] = lastName;
    map["bvn_number"] = bvnNumber;
    map["phone_number"] = phoneNumber;
    map["dob"] = dob;
    return map;
  }
}

/// Data class for PVC Verification Request

class PVCRequest {
  String _firstName, _lastName, _pvcNumber, _phoneNumber, _dob, _state;

  PVCRequest(this._firstName, this._lastName, this._pvcNumber,
      this._phoneNumber, this._dob, this._state);

  String get firstName => _firstName;
  String get lastName => _lastName;
  String get pvcNumber => _pvcNumber;
  String get phoneNumber => _phoneNumber;
  String get dob => _dob;
  String get state => _state;

  PVCRequest.map(dynamic obj) {
    this._firstName = obj["first_name"];
    this._lastName = obj["last_name"];
    this._pvcNumber = obj["bvn_number"];
    this._phoneNumber = obj["phone_number"];
    this._dob = obj["dob"];
    this._state = obj["state"];
  }

  PVCRequest.fromJson(Map<String, dynamic> json)
    : _firstName = json['first_name'],
     _lastName = json['last_name'],
     _pvcNumber = json['pvc_number'],
     _phoneNumber = json['phone_number'],
     _dob = json['dob'],
    _state = json['state'];

  Map<String, dynamic> toJson() {
    var map = new Map<String, dynamic>();
    map["first_name"] = _firstName;
    map["last_name"] = _lastName;
    map["pvc_number"] = _pvcNumber;
    map["phone_number"] = _phoneNumber;
    map["dob"] = _dob;
    map["state"] = _state;
    return map;
  }
}

class NINRequest {
  String _ninNumber, _phoneNumber;

  NINRequest(this._ninNumber,
      this._phoneNumber);


  String get pvcNumber => _ninNumber;
  String get phoneNumber => _phoneNumber;

  NINRequest.map(dynamic obj) {
    this._ninNumber = obj["nin_number"];
    this._phoneNumber = obj["phone_number"];
  }

  NINRequest.fromJson(Map<String, dynamic> json)
      :_ninNumber = json['nin_number'],
        _phoneNumber = json['phone_number'];

  Map<String, dynamic> toJson() {
    var map = new Map<String, dynamic>();
    map["nin_number"] = _ninNumber;
    map["phone_number"] = _phoneNumber;
    return map;
  }
}

/// Data class for Driver's Licence Verification Request

class DLRequest {
  String _dlNumber, _phoneNumber;

  DLRequest(this._dlNumber,
      this._phoneNumber);


  String get pvcNumber => _dlNumber;
  String get phoneNumber => _phoneNumber;

  DLRequest.map(dynamic obj) {
    this._dlNumber = obj["licence_number"];
    this._phoneNumber = obj["phone_number"];
  }

  DLRequest.fromJson(Map<String, dynamic> json)
      : _dlNumber = json['licence_number'],
        _phoneNumber = json['phone_number'];

  Map<String, dynamic> toJson() {
    var map = new Map<String, dynamic>();
    map["licence_number"] = _dlNumber;
    map["phone_number"] = _phoneNumber;
    return map;
  }
}

/// Data class for NIP Verification Request

class NIPRequest {
  String _passportNumber, _phoneNumber;

  NIPRequest(this._passportNumber,
      this._phoneNumber);


  String get pvcNumber => _passportNumber;
  String get phoneNumber => _phoneNumber;

  NIPRequest.map(dynamic obj) {
    this._passportNumber = obj["passport_number"];
    this._phoneNumber = obj["phone_number"];
  }

  NIPRequest.fromJson(Map<String, dynamic> json)
      : _passportNumber = json['passport_number'],
        _phoneNumber = json['phone_number'];

  Map<String, dynamic> toJson() {
    var map = new Map<String, dynamic>();
    map["passport_number"] = _passportNumber;
    map["phone_number"] = _phoneNumber;
    return map;
  }
}


class DataCaptureRequest {
  String _phoneNumber;
  int _identityTypeId;
  File _idCardFrontImage, _idCardBackImage;


  DataCaptureRequest(this._phoneNumber, this._identityTypeId,
      this._idCardFrontImage, this._idCardBackImage);

  DataCaptureRequest.map(dynamic obj) {
    this._identityTypeId = obj["identity_type_id"];
    this._phoneNumber = obj["phone_number"];
    this._idCardFrontImage = obj["id_card_front_image"];
    this._idCardFrontImage = obj["id_card_back_image"];
  }

  DataCaptureRequest.fromJson(Map<String, dynamic> json)
      : _identityTypeId = json['identity_type_id'],
        _phoneNumber = json['phone_number'],
        _idCardFrontImage = json['id_card_front_image'],
        _idCardBackImage = json['id_card_back_image'];

  Map<String, dynamic> toJson() {
    var map = new Map<String, dynamic>();
    map["identity_type_id"] = _identityTypeId;
    map["phone_number"] = _phoneNumber;
    map["id_card_front_image"] = _idCardFrontImage;
    map["id_card_back_image"] = _idCardBackImage;
    return map;
  }

}

class FacialComparisonRequest {
  File _image1, _image2;

  FacialComparisonRequest(this._image1, this._image2);

  FacialComparisonRequest.map(dynamic obj) {
    this._image1 = obj["image_1"];
    this._image2 = obj["image_2"];
  }

  FacialComparisonRequest.fromJson(Map<String, dynamic> json)
      : _image1 = json['image_1'],
        _image2 = json['image_2'];

  Map<String, dynamic> toJson() {
    var map = new Map<String, dynamic>();
    map["image_1"] = _image1;
    map["image_2"] = _image2;
    return map;
  }
}

class LivenessCheckInitRequest {
  File _imageRef;

  LivenessCheckInitRequest(this._imageRef);

  LivenessCheckInitRequest.map(dynamic obj){
    this._imageRef = obj["image_ref"];
  }

  LivenessCheckInitRequest.fromJson(Map<String, dynamic> json)
    : _imageRef = json['image_ref'];

  Map<String, dynamic> toJson() => {
    'image_ref' : _imageRef
  };

}