import 'dart:collection';

import 'package:http/http.dart' as http;
import 'package:http_interceptor/http_interceptor.dart';

class HttpClient{

  static const BASE_URL = "https://api.dev.blusalt.io/api/";
  static var  _client = HttpClientWithInterceptor.build(interceptors: [
  LogginInterceptor(),
  ]);

  Future<http.Response> _makeGetRequest(String url, ApiCredentials credentials, body){
    HashMap<String, String> headers = _createHeadersFromCredentials(credentials);
    return _client.get(url, headers: headers);
  }

  Future<http.Response> _makePostRequest(String url, ApiCredentials credentials, dynamic body){
    HashMap<String, String> headers = _createHeadersFromCredentials(credentials);
    final link = BASE_URL + url;
    return _client.post(link, headers: headers, body: body);
  }

  HashMap<String, String> _createHeadersFromCredentials(ApiCredentials credentials) {
    var headers = new HashMap<String, String>();
    headers["clientid"] = credentials.clientID;
    headers["appname"] = credentials.appName;
    headers["apikey"] = credentials.apiKey;
    headers["Content-Type"] = "application/json";
    return headers;
  }
  
  Future<dynamic> executeRequest(Request request){
    switch(request.requestMethod){
      case Method.GET:
        return _makeGetRequest(request.url, request.apiCredentials, request.body);
      case Method.HEAD:
        // TODO: Handle this case.
        break;
      case Method.POST:
        return _makePostRequest(request.url, request.apiCredentials, request.body);
      case Method.PUT:
        // TODO: Handle this case.
        break;
      case Method.PATCH:
        // TODO: Handle this case.
        break;
      case Method.DELETE:
        // TODO: Handle this case.
        break;
    }
    return null;
  }

  Future<http.Response> initializeSDK(ApiCredentials credentials){
    String url = BASE_URL + "App/InitializeApp";
    return _makeGetRequest(url, credentials, null);
  }
}

class ApiCredentials {
  String apiKey, clientID, appName;
  ApiCredentials({this.apiKey, this.clientID, this.appName});
}

class Request{
  dynamic url, body;
  ApiCredentials apiCredentials;
  Method requestMethod;

  Request({this.url, this.body, this.apiCredentials, this.requestMethod});


}

class LogginInterceptor implements InterceptorContract {
  @override
  Future<RequestData> interceptRequest({RequestData data}) async {
    print(" ${data.method} Request at ${data.url}");
    print(" On ${data.headers} ${data.body}");
    return data;
  }

  @override
  Future<ResponseData> interceptResponse({ResponseData data}) async {
    print(" ${data.method} Response from ${data.url}");
    print("${data.headers}");
    print("${data.body}");
    return data;
  }

}