import 'dart:convert';

import 'package:blusalt_identity/common/exception.dart';
import 'package:blusalt_identity/model/dl_response.dart';
import 'package:blusalt_identity/model/nin_response.dart';
import 'package:blusalt_identity/model/nip_response.dart';
import 'package:blusalt_identity/model/pvc_response.dart';
import 'package:blusalt_identity/model/request.dart';
import 'package:blusalt_identity/network/blusalt_sdk.dart';
import 'package:blusalt_identity/network/network_client.dart' as client;
import 'package:http/http.dart';
import 'package:http_interceptor/http_interceptor.dart';

import 'model/bvn_response.dart';

var _netWorkClient = client.HttpClient();

Future<BVNResponse> verifyBVN(BVNRequest bvnRequest) {
  if (BlusaltSDK.apiCredentials == null) {
    throw InitializationException(
        "SDK initilization Failed. Please Initialize SDK ");
  }

  var response = _netWorkClient.executeRequest(client.Request(
    url: "IdentityVerification/BVN",
    body: jsonEncode(bvnRequest),
    apiCredentials: BlusaltSDK.apiCredentials,
    requestMethod:  Method.POST
  ));

  response.then((onValue) {
    var data = onValue as Response;
    var bvnData = BVNResponse.fromJson(jsonDecode(data.body));
    if (bvnData.statusCode == 200) {
      return Future.value(bvnData);
    } else {
      return Future.error(NetworkResponseError(
          "Code: ${bvnData.statusCode} Message: ${bvnData.message}"));
    }
  });

  response.catchError((onError) {
    return Future.error(onError);
  });
  return null;
}

Future<NINResponse> verifyNIN(NINRequest ninRequest) {
  if (BlusaltSDK.apiCredentials == null) {
    throw InitializationException(
        "SDK initilization Failed. Please Initialize SDK ");
  }

  var response = _netWorkClient.executeRequest(client.Request(
      url: "IdentityVerification/NIN",
      body: jsonEncode(ninRequest),
      apiCredentials: BlusaltSDK.apiCredentials,
      requestMethod:  Method.POST
  ));
  response.then((onValue) {
    var data = onValue as Response;
    var ninData = NINResponse.fromJson(jsonDecode(data.body));
    if (ninData.statusCode == 200) {
      return Future.value(ninData);
    } else {
      return Future.error(NetworkResponseError(
          "Code: ${ninData.statusCode} Message: ${ninData.message}"));
    }
  });

  response.catchError((onError) {
    return Future.error(onError);
  });
  return null;
}

Future<NIPResponse> verifyNIP(NIPRequest request) {
  if (BlusaltSDK.apiCredentials == null) {
    throw InitializationException(
        "SDK initilization Failed. Please Initialize SDK ");
  }

  var response = _netWorkClient.executeRequest(client.Request(
      url: "IdentityVerification/NIP",
      body: jsonEncode(request),
      apiCredentials: BlusaltSDK.apiCredentials,
      requestMethod:  Method.POST
  ));
  response.then((onValue) {
    var data = onValue as Response;
    var nipData = NIPResponse.fromJson(jsonDecode(data.body));
    if (nipData.statusCode == 200) {
      return Future.value(nipData);
    } else {
      return Future.error(NetworkResponseError(
          "Code: ${nipData.statusCode} Message: ${nipData.message}"));
    }
  });

  response.catchError((onError) {
    return Future.error(onError);
  });
  return null;
}

Future<PVCResponse> verifyPVC(PVCRequest request) {
  if (BlusaltSDK.apiCredentials == null) {
    throw InitializationException(
        "SDK initilization Failed. Please Initialize SDK ");
  }

  var response = _netWorkClient.executeRequest(client.Request(
      url: "IdentityVerification/PVC",
      body: jsonEncode(request),
      apiCredentials: BlusaltSDK.apiCredentials,
      requestMethod:  Method.POST
  ));
  response.then((onValue) {
    var data = onValue as Response;
    var pvcData = PVCResponse.fromJson(jsonDecode(data.body));
    if (pvcData.statusCode == 200) {
      return Future.value(pvcData);
    } else {
      return Future.error(NetworkResponseError(
          "Code: ${pvcData.statusCode} Message: ${pvcData.message}"));
    }
  });

  response.catchError((onError) {
    return Future.error(onError);
  });
  return null;
}

Future<DLResponse> verifyDriversLicence(DLRequest request) {
  if (BlusaltSDK.apiCredentials == null) {
    throw InitializationException(
        "SDK initilization Failed. Please Initialize SDK ");
  }

  var response = _netWorkClient.executeRequest(client.Request(
      url: "IdentityVerification/DriverLicence",
      body: jsonEncode(request),
      apiCredentials: BlusaltSDK.apiCredentials,
      requestMethod:  Method.POST
  ));
  response.then((onValue) {
    var data = onValue as Response;
    var dlData = DLResponse.fromJson(jsonDecode(data.body));
    if (dlData.statusCode == 200) {
      return Future.value(dlData);
    } else {
      return Future.error(NetworkResponseError(
          "Code: ${dlData.statusCode} Message: ${dlData.message}"));
    }
  });

  response.catchError((onError) {
    return Future.error(onError);
  });
  return null;
}
